=== modified file 'baz2bzr'
--- baz2bzr	2005-06-03 17:35:36 +0000
+++ baz2bzr	2005-06-03 17:53:35 +0000
@@ -172,7 +172,7 @@
     return ancestors
 
 
-def import_version(output_dir, version, fancy=True):
+def import_version(output_dir, version, fancy=True, fast=False, verbose=False, dry_run=False, max_count=None):
     """
     >>> q = test_environ()
     >>> result_path = os.path.join(q, "result")
@@ -181,6 +181,7 @@
     >>> import_version(result_path, version, fancy=False)
     not fancy
     ....
+    Cleaning up
     Import complete.
     >>> teardown_environ(q)
     """
@@ -190,7 +191,8 @@
     try:
         if not fancy:
             print "not fancy"
-        for result in iter_import_version(output_dir, version, tempdir):
+        for result in iter_import_version(output_dir, version, tempdir,
+                fast=fast, verbose=verbose, dry_run=dry_run, max_count=max_count):
             if fancy:
                 progress_bar(result)
             else:
@@ -200,6 +202,7 @@
             clear_progress_bar()
         else:
             sys.stdout.write('\n')
+        print 'Cleaning up'
         shutil.rmtree(tempdir)
     print "Import complete."
             
@@ -224,7 +227,7 @@
     """
     return "Arch-x:%s" % str(arch_revision).replace('/', '%')
 
-def iter_import_version(output_dir, version, tempdir):
+def iter_import_version(output_dir, version, tempdir, fast=False, verbose=False, dry_run=False, max_count=None):
     revdir = None
     ancestors = version_ancestry(version)
     last_patch = None
@@ -270,11 +273,31 @@
 
     # Uncomment this for testing, it basically just has baz2bzr only update
     # 5 patches at a time
-    #ancestors = ancestors[:5]
+    if max_count:
+        ancestors = ancestors[:max_count]
+
+    # Not sure if I want this output. basically it tells you ahead of time
+    # what it is going to do, but then later it tells you as it is doing it.
+    # what probably would be best would be to collapse it into ranges, so that
+    # this gives the simple view, and then later it gives the blow by blow.
+    #if verbose:
+    #    print 'Adding the following revisions:'
+    #    for a in ancestors:
+    #        print '\t%s' % a
+
+    previous_version=None
 
     for i in range(len(ancestors)):
         revision = ancestors[i]
-        yield Progress("revisions", i, len(ancestors))
+        if verbose:
+            version = str(revision.version)
+            if version != previous_version:
+                clear_progress_bar()
+                print '\rOn version: %s' % version
+            yield Progress(str(revision.patchlevel), i, len(ancestors))
+            previous_version = version
+        else:
+            yield Progress("revisions", i, len(ancestors))
         if revdir is None:
             revdir = os.path.join(tempdir, "rd")
             baz_inv, log = get_revision(revdir, revision, skip_symlink=True)
@@ -299,6 +322,9 @@
             branch.unlock()
     yield Progress("revisions", len(ancestors), len(ancestors))
     unlink_unversioned(branch, revdir)
+    if dry_run:
+        print '**Dry run, not modifying output_dir'
+        return
     if os.path.exists(output_dir):
         # Move the bzr control directory back, and update the working tree
         tmp_bzr_dir = os.path.join(tempdir, '.bzr')
@@ -388,17 +414,71 @@
     bzr_inv.sort()
     return bzr_inv
 
-if len(sys.argv) == 2 and sys.argv[1] == "test":
-    print "Running tests"
-    import doctest
-    doctest.testmod()
-elif len(sys.argv) == 3:
-    try:
-        output_dir = os.path.realpath(sys.argv[2])
-        import_version(output_dir, pybaz.Version(sys.argv[1]))
-    except UserError, e:
-        print e
-    except KeyboardInterrupt:
-        print "Aborted."
-else:
-    print "usage: %s VERSION OUTDIR" % os.path.basename(sys.argv[0])
+def main(args):
+    """Just the main() function for this script.
+
+    By separating it into a function, this can be called as a child from some other
+    script.
+
+    :param args: The arguments to this script. Essentially sys.argv[1:]
+    """
+    import optparse
+    parser = optparse.OptionParser(usage='%prog [options] VERSION OUTDIR'
+        '\n  VERSION is the arch version to import.'
+        '\n  OUTDIR can be an existing directory to be updated'
+        '\n         or a new directory which will be created from scratch.')
+    parser.add_option('--verbose', action='store_true'
+        , help='Get chatty')
+
+    g = optparse.OptionGroup(parser, 'Progress options', 'Control how progress is given')
+    g.add_option('--not-fancy', dest='fancy', action='store_false')
+    g.add_option('--fancy', dest='fancy', action='store_true', default=True
+        , help='Fancy or simple progress bar. (default: fancy)')
+    parser.add_option_group(g)
+
+    g = optparse.OptionGroup(parser, 'Test options', 'Options useful while testing process.')
+    g.add_option('--test', action='store_true'
+        , help='Run the self-tests and exit.')
+    g.add_option('--dry-run', action='store_true'
+        , help='Do the update, but don\'t copy the result to OUTDIR')
+    g.add_option('--max-count', type='int', metavar='COUNT', default=None
+        , help='At most, add COUNT patches.')
+    g.add_option('--safe', action='store_false', dest='fast')
+    g.add_option('--fast', action='store_true', default=False
+        , help='By default the .bzr control directory will be copied, so that an error'
+        ' does not modify the original. --fast allows the directory to be renamed instead.')
+    parser.add_option_group(g)
+
+    (opts, args) = parser.parse_args(args)
+
+    if opts.test:
+        print "Running tests"
+        import doctest
+        nfail, ntests = doctest.testmod(verbose=opts.verbose)
+        if nfail > 0:
+            return 1
+        else:
+            return 0
+
+    if len(args) != 2:
+        print 'Invalid number of arguments, try --help for more info'
+        return 1
+    else:
+        try:
+            output_dir = os.path.realpath(args[1])
+            import_version(output_dir, pybaz.Version(args[0]),
+                verbose=opts.verbose, fast=opts.fast,
+                fancy=opts.fancy, dry_run=opts.dry_run,
+                max_count=opts.max_count)
+            return 0
+        except UserError, e:
+            print e
+            return 1
+        except KeyboardInterrupt:
+            print "Aborted."
+            return 1
+
+
+if __name__ == '__main__':
+    sys.exit(main(sys.argv[1:]))
+

